@@ -47,7 +47,7 @@
 
 get_paleo <- function(use_cache = TRUE, write_cache = getOption("hs_write_cache")) {
 
-  hs_path <- rappdirs::user_cache_dir("hockeystick")
+  hs_path <- tools::R_user_dir("hockeystick","cache")
 
   if (use_cache) {
     if (file.exists(file.path(hs_path,'paleo.rds'))) return(invisible(readRDS((file.path(hs_path,'paleo.rds')))))
